Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1014)

Unified Diff: chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc

Issue 24733003: Update defaults for InstantExtended. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove unused. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/policy/policy_browsertest.cc ('k') | chrome/browser/search/instant_service_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
diff --git a/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc b/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
index a17ec4213259ac8cf61e57b31d01fa548e370c51..50bcf5907a389af7c8f51ad9392cd4f70dec8e82 100644
--- a/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
+++ b/chrome/browser/renderer_host/render_process_host_chrome_browsertest.cc
@@ -93,13 +93,13 @@ class ChromeRenderProcessHostTest : public InProcessBrowserTest {
content::RenderProcessHost* rph2 = NULL;
content::RenderProcessHost* rph3 = NULL;
- // Change the first tab to be the new tab page (TYPE_WEBUI).
- GURL newtab(chrome::kChromeUINewTabURL);
- ui_test_utils::NavigateToURL(browser(), newtab);
+ // Change the first tab to be the omnibox page (TYPE_WEBUI).
+ GURL omnibox(chrome::kChromeUIOmniboxURL);
+ ui_test_utils::NavigateToURL(browser(), omnibox);
EXPECT_EQ(tab_count, browser()->tab_strip_model()->count());
tab1 = browser()->tab_strip_model()->GetWebContentsAt(tab_count - 1);
rph1 = tab1->GetRenderProcessHost();
- EXPECT_TRUE(chrome::IsNTPURL(tab1->GetURL(), browser()->profile()));
+ EXPECT_EQ(omnibox, tab1->GetURL());
EXPECT_EQ(host_count, RenderProcessHostCount());
// Create a new TYPE_TABBED tab. It should be in its own process.
@@ -132,7 +132,7 @@ class ChromeRenderProcessHostTest : public InProcessBrowserTest {
EXPECT_EQ(host_count, RenderProcessHostCount());
EXPECT_EQ(tab2->GetRenderProcessHost(), rph2);
// Create another TYPE_WEBUI tab. It should share the process with newtab.
// Note: intentionally create this tab after the TYPE_TABBED tabs to
// exercise bug 43448 where extension and WebUI tabs could get combined into
// normal renderers.
@@ -187,8 +187,8 @@ IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest, ProcessPerTab) {
int host_count = 1;
// Change the first tab to be the new tab page (TYPE_WEBUI).
- GURL newtab(chrome::kChromeUINewTabURL);
- ui_test_utils::NavigateToURL(browser(), newtab);
+ GURL omnibox(chrome::kChromeUIOmniboxURL);
+ ui_test_utils::NavigateToURL(browser(), omnibox);
EXPECT_EQ(tab_count, browser()->tab_strip_model()->count());
EXPECT_EQ(host_count, RenderProcessHostCount());
@@ -213,20 +213,20 @@ IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest, ProcessPerTab) {
EXPECT_EQ(tab_count, browser()->tab_strip_model()->count());
EXPECT_EQ(host_count, RenderProcessHostCount());
- // Create another new tab. It should share the process with the other WebUI.
- ui_test_utils::WindowedTabAddedNotificationObserver observer3(
- content::NotificationService::AllSources());
- chrome::NewTab(browser());
- observer3.Wait();
+ // Create another omnibox tab. It should share the process with the other
+ // WebUI.
+ ui_test_utils::NavigateToURLWithDisposition(
+ browser(), omnibox, NEW_FOREGROUND_TAB,
+ ui_test_utils::BROWSER_TEST_WAIT_FOR_NAVIGATION);
tab_count++;
EXPECT_EQ(tab_count, browser()->tab_strip_model()->count());
EXPECT_EQ(host_count, RenderProcessHostCount());
- // Create another new tab. It should share the process with the other WebUI.
- ui_test_utils::WindowedTabAddedNotificationObserver observer4(
- content::NotificationService::AllSources());
- chrome::NewTab(browser());
- observer4.Wait();
+ // Create another omnibox tab. It should share the process with the other
+ // WebUI.
+ ui_test_utils::NavigateToURLWithDisposition(
+ browser(), omnibox, NEW_FOREGROUND_TAB,
+ ui_test_utils::BROWSER_TEST_WAIT_FOR_NAVIGATION);
tab_count++;
EXPECT_EQ(tab_count, browser()->tab_strip_model()->count());
EXPECT_EQ(host_count, RenderProcessHostCount());
@@ -243,9 +243,9 @@ IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest, Backgrounding) {
CommandLine& parsed_command_line = *CommandLine::ForCurrentProcess();
parsed_command_line.AppendSwitch(switches::kProcessPerTab);
- // Change the first tab to be the new tab page (TYPE_WEBUI).
- GURL newtab(chrome::kChromeUINewTabURL);
- ui_test_utils::NavigateToURL(browser(), newtab);
+ // Change the first tab to be the omnibox page (TYPE_WEBUI).
+ GURL omnibox(chrome::kChromeUIOmniboxURL);
+ ui_test_utils::NavigateToURL(browser(), omnibox);
// Create a new tab. It should be foreground.
GURL page1("data:text/html,hello world1");
@@ -419,7 +419,7 @@ class WindowDestroyer : public content::WebContentsObserver {
// access already freed objects. See http://crbug.com/255524.
IN_PROC_BROWSER_TEST_F(ChromeRenderProcessHostTest,
CloseAllTabsDuringProcessDied) {
- GURL url(chrome::kChromeUINewTabURL);
+ GURL url(chrome::kChromeUIOmniboxURL);
ui_test_utils::NavigateToURL(browser(), url);
ui_test_utils::NavigateToURLWithDisposition(
« no previous file with comments | « chrome/browser/policy/policy_browsertest.cc ('k') | chrome/browser/search/instant_service_unittest.cc » ('j') | no next file with comments »
@@ -132,7 +132,7 @@ class ChromeRenderProcessHostTest : public InProcessBrowserTest {
EXPECT_EQ(host_count, RenderProcessHostCount());
EXPECT_EQ(tab2->GetRenderProcessHost(), rph2);
- // Create another TYPE_WEBUI tab. It should share the process with newtab.
+ // Create another TYPE_WEBUI tab. It should share the process with omnibox.
// Note: intentionally create this tab after the TYPE_TABBED tabs to
// exercise bug 43448 where extension and WebUI tabs could get combined into

Powered by Google App Engine
This is Rietveld 408576698